@@ -21,11 +21,13 @@ trip = pyrmv.trip_find(access_id, origin_id=origin.id, dest_id=destination.id)
 """
 
 __name__ = "pyrmv"
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 __license__ = "MIT License"
 __author__ = "Profitroll"
 
 from . import raw
+from . import const
+from . import enums
 from . import errors
 from . import utility
 from . import classes
